#
# spec file for package libvmdk
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}

%define lname	libvmdk1
Name:           libvmdk
Version:        20240303
Release:        1.5
Summary:        Library to access the VMware Virtual Disk (VMDK) format
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Productivity/File utilities
URL:            https://github.com/libyal/libvmdk/
Source:         https://github.com/libyal/libvmdk/releases/download/%version/libvmdk-alpha-%version.tar.gz
Source2:        https://github.com/libyal/libvmdk/releases/download/%version/libvmdk-alpha-%version.tar.gz.asc
Source3:        %name.keyring
Source11:       VMWare_Virtual_Disk_Format_VMDK.pdf
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  c_compiler
BuildRequires:  pkg-config
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(fuse)
BuildRequires:  pkgconfig(libbfio) >= 20221025
BuildRequires:  pkgconfig(libcdata) >= 20240103
BuildRequires:  pkgconfig(libcerror) >= 20240101
BuildRequires:  pkgconfig(libcfile) >= 20240106
BuildRequires:  pkgconfig(libclocale) >= 20240107
BuildRequires:  pkgconfig(libcnotify) >= 20240108
BuildRequires:  pkgconfig(libcpath) >= 20240109
BuildRequires:  pkgconfig(libcsplit) >= 20240110
BuildRequires:  pkgconfig(libcthreads) >= 20240102
BuildRequires:  pkgconfig(libfcache) >= 20240112
BuildRequires:  pkgconfig(libfdata) >= 20240114
BuildRequires:  pkgconfig(libfvalue) >= 20240124
BuildRequires:  pkgconfig(libuna) >= 20240130
BuildRequires:  pkgconfig(zlib)
%python_subpackages
# Various notes: https://en.opensuse.org/libyal

%description
The libvmdk library is a library to access the VMware Virtual Disk (VMDK) format.

%package -n %lname
Summary:        Library to access the VMDK image format
License:        LGPL-3.0-or-later
Group:          System/Libraries

%description -n %lname
The libvmdk library is a library to access the VMware Virtual Disk (VMDK) format.

Read supported extent file formats:

* RAW (flat)
* COWD version 1 (sparse)
* VMDK version 1, 2 and 3 (sparse)

Supported VMDK format features:

* delta links
* grain compression
* data markers

VMDK format features not supported at the moment:

* images that use a physical device
* changed block tracking (CBT) (supported by VMDK version 3 (sparse)) / change tracking files

%package tools
Summary:        Tools to access the VMDK image format
License:        LGPL-3.0-or-later
Group:          Productivity/File utilities

%description tools
Several tools for accessing VMware Virtual Disk (VMDK) files.

See libvmdk for additional details.

%package devel
Summary:        Header files and libraries for developing applications for libvmdk
License:        GFDL-1.3-or-later AND LGPL-3.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %lname = %version
Requires:       libbfio-devel

%description devel
The libvmdk library is a library to access the VMware Virtual Disk (VMDK) format.

See libvmdk for additional details.

This package contains libraries and header files for developing
applications that want to make use of libvmdk.

%prep
%autosetup -p1
cp %_sourcedir/*.pdf .

%build
%{python_expand #
echo "V_%version { global: *; };" >v.sym
%configure --disable-static --enable-wide-character-type \
	--enable-python PYTHON_VERSION="%{$python_bin_suffix}" \
	LDFLAGS="-Wl,--version-script=$PWD/v.sym"
grep ' '' ''local' config.log && exit 1
%make_build
%make_install DESTDIR="%_builddir/rt"
%make_build clean
}

%install
mv %_builddir/rt/* %buildroot/
find %buildroot -type f -name "*.la" -delete -print

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%license COPYING*
%_libdir/libvmdk.so.*

%files -n %name-tools
%license COPYING*
%_bindir/vmdk*
%_mandir/man1/vmdk*.1*

%files -n %name-devel
%license COPYING*
%doc VMWare_Virtual_Disk_Format*
%_includedir/libvmdk.h
%_includedir/libvmdk/
%_libdir/libvmdk.so
%_libdir/pkgconfig/libvmdk.pc
%_mandir/man3/libvmdk.3*

%files %python_files
%license COPYING*
%python_sitearch/pyvmdk.so

%changelog
* Sun Mar  3 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 20240303
  * No user-visible changes
* Mon Feb  5 2024 Jan Engelhardt <jengelh@inai.de>
- Use python-setuptools for python distutils backport
  gh#libyal/libbde#68
* Thu Nov 23 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 20231123
  * Improve Python3 Unicode handling
* Tue Aug  1 2023 Greg Freemyer <Greg.Freemyer@gmail.com>
- use %%{?sle15_python_module_pythons} for opensuse15.5 compatibility
* Tue Jan  3 2023 Jan Engelhardt <jengelh@inai.de>
- Add missing Require on libbfio-devel.
* Sat Nov 26 2022 Jan Engelhardt <jengelh@inai.de>
- Delete system-libs.patch (not needed - system libs are
  autodetected)
* Thu Nov 24 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 20221124
  * Added alternate extent data filename support
  * Added Shift_JIS encoding support
  * A refcounting issue with the Python module was fixed
* Mon Aug  8 2022 Jan Engelhardt <jengelh@inai.de>
- Add forced symvers
* Mon Jan 24 2022 Jan Engelhardt <jengelh@inai.de>
- Enable multipython builds. (This reenables Python2 on Leap 15.)
* Sun Nov 14 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 20210807
  * Python binding updates
* Sun May 16 2021 Jan Engelhardt <jengelh@inai.de>
- Update to snapshot 20210418 (4601e0bd)
  * No changelog was provided
- Add system-libs.patch
* Thu Dec 24 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- Update to 20200926
  * Added Big5 as an alias for CP950
  * Added GBK as an alias for CP936
* Thu Apr 30 2020 Greg Freemyer <Greg.Freemyer@gmail.com>
- remove python2 submodule
* Tue Apr 16 2019 Greg Freemyer <Greg.Freemyer@gmail.com>
- Update to 20181227
  * Extended pyvmdk with disk and extent types
  * Fixed issue in fallback inflate implementation
  * Worked on mount tool
* Wed Oct  4 2017 Greg.Freemyer@gmail.com
- rename python-libvmdk to python2-libvmdk as expected by singlespec
- remove Provides pyvmdk as it is not versioned
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- Update to 20170226
  * worked on python bindings
  * code clean up
  * worked on internal tests
- disabled tests - they no longer compile
- use internal version of libcnotify
- Change Group: field for the python bindings to devel/languages/python
* Fri Jul  1 2016 toddrme2178@gmail.com
- Enable tests
- Build against external versions of all libraries.
  They work now.
- rename doc file to eliminate () due to new security chec
* Thu Jun 30 2016 toddrme2178@gmail.com
- Update to 20160124
  * 2016 update
  * changes for deployment
  * Changes to Python bindings
  * fixed bug handling extent without filename
  * fixed bug in basename handling on non UTF-8 system string systems
  * fixed memory leak
  * fixes for rpmbuild
  * updated dependencies
  * worked on fallback inflate implementation
  * worked on Python 3 support
  * worked on Python bindings
  * worked on tests
- Build with fuse.  If not, mounting doesn't work.
- Build python 3 bindings.
- Update summaries and descriptions based on upstream spec file.
* Mon Jan  5 2015 Greg.Freemyer@gmail.com
- update to v0~20150105
  * worked on Python 3 support
  * worked on tests
  * worked on test scripts
  * code clean up
  * small fixes for stand-alone usage of libfvalue
  * worked on multi-threading support
  * added tests/pyvmdk_test_open_close.py to make dist
  * bug fix in Python-bindings
- update URL field to point to the new github site
- update Source: field to be a fully defined URL
- deleted the DL-URL comment
- update the BuildRequires based on what works from OBS
- remove %%if for opensuse version, not needed with libyal consolidated in decurity:forensics
* Mon Aug 25 2014 Greg.Freemyer@gmail.com
- remove reference to GFDL-1.1+.  Supplemental docs were GFDL-1.3+ only.
* Sat Aug 23 2014 Greg.Freemyer@gmail.com
- initial package in OBS (0v20140803)
